TargetState

Struct TargetState 

pub struct TargetState<T, V> {
    pub target: T,
    pub value: V,
}
Generic target and state

Fields

target: T

The target type

value: V

The target’s value or property

Implementations

Source

impl<T, V> TargetState<T, V>

pub fn new(target: T, value: V) -> Self

Create new TargetState from target and initial value Recommended to use other methods like:

pub fn set_value(&mut self, new_value: V) -> &mut Self

Change the value

pub fn set_target(&mut self, new_target: T) -> &mut Self

Change the target

Source

impl<T, V> TargetState<T, V>
where T: Clone,

pub fn with<I>(&mut self, f: impl FnOnce(&mut V) -> I) -> Tween<T, I>

Create ComponentTween of a value from this state and relative interpolator constructor

Examples
use bevy_tween::interpolate::translation_to;

let my_target = sprite.into_target();
let mut my_target_translation = my_target.state(Vec3::ZERO);

// Creating a ComponentTween that's tweening from previous value to Vec3::ONE
let tween = my_target_translation.with(translation_to(Vec3::ONE));